import type { Ref } from 'vue';
import { getApiUrl } from './net';
import type { Game, Teams } from './models';
import { downloadData } from './qr';

export const apiGetTeams = async (): Promise<Teams> => {
  try {
    const response = await fetch(
      getApiUrl("/teams")
    )
    if (!response.ok) {
      throw new Error(`http error status: ${response.status}`)
    }
    return await response.json()
  } catch (error) {
    console.error('[apiGetTeams] error:', error)
    throw error
  }
}

export const apiAddTeam = async (teamName: string) => {
  try {
    const response = await fetch(
      getApiUrl("/teams"),
      {
        method: "POST",
        body: JSON.stringify({
          "teams": [{ "name": teamName }]
        })
      }
    )
    if (!response.ok) {
      throw new Error(`http error status: ${response.status}`)
    }
    return await response.json()
  } catch (error) {
    console.error('[apiAddTeam] error:', error)
    throw error
  }
}

export const apiGetGame = (game: Ref<Game | undefined>, gameState: Ref<string>) => {
  fetch(
    getApiUrl("/game")
  )
  .then(response => response.json())
  .then(data => {
    game.value = data
    if (data.state === "NEW") {
      gameState.value = "Игра ещё не началась"
    }
    if (data.state === "RUN") {
      gameState.value = "Игра идет с " + game.value?.startAt.substring(11)
    }
    if (data.state === "STOP") {
      gameState.value = "Игра остановлена " + game.value?.startAt.substring(11) + " - " + game.value?.endAt.substring(11)
    }
  })
  .catch(error => {
    console.error('Ошибка:', error)
  });
}

export const apiStartGame = (gameState: Ref<string>) => {
  gameState.value = "Загрузка..."
  fetch(
    getApiUrl("/game/start"),
    { method: "POST" }
  )
    .catch(error => {
      console.error('Ошибка:', error)
    });
}

export const apiStopGame = (gameState: Ref<string>) => {
  gameState.value = "Загрузка..."
  fetch(
    getApiUrl("/game/stop"),
    { method: "POST" }
  )
  .catch(error => {
    console.error('Ошибка:', error)
  });
}


export const apiGaveApplication = (teamId: number, id: number) => {
  fetch(
    getApiUrl("/teams/" + teamId + "/applications"),
    {
      method: "POST",
      body: JSON.stringify({
        "applications": [{ "id": id }]
      })
    }
  )
  .then(() => { })
  .catch(error => {
    console.error('Ошибка:', error)
  });
}

export const apiDownloadQrCodesFile = () => {
  fetch(
    getApiUrl("/teams/pdf")
  )
  .then(response => response.json())
  .then(data => {
    downloadData(data.result)
  })
  .catch(error => {
    console.error('Ошибка:', error)
  });
}
